@@ -1,3 +1,5 @@
+#!/bin/env python3
+
 # mcctl: A Minecraft Server Management Utility written in Python
 # Copyright (C) 2020 Matthias Cotting
 
@@ -16,6 +18,8 @@
 # You should have received a copy of the GNU General Public License
 # along with mcctl. If not, see <http://www.gnu.org/licenses/>.
 
-from mcctl import config, proc, service, storage, web, common, settings
 
-__version__ = "0.2.2"
+__version__ = "0.3.0"
+
+from mcctl.__config__ import CFGVARS  # noqa: F401
+from mcctl import common, config, proc, service, storage, visuals, web  # noqa: F401
